@@ -10,6 +10,8 @@ use std::sync::Arc;
 use bevy::ecs::schedule::ShouldRun;
 use bevy::prelude::*;
 
+#[cfg(feature = "collision-from-mesh")]
+pub use collision_from_mesh::PendingConvexCollision;
 pub use constraints::RotationConstraints;
 pub use events::{CollisionData, CollisionEvent};
 pub use gravity::Gravity;
@@ -18,6 +20,8 @@ pub use physics_time::PhysicsTime;
 pub use step::{PhysicsStepDuration, PhysicsSteps};
 pub use velocity::{Acceleration, AxisAngle, Damping, Velocity};
 
+#[cfg(feature = "collision-from-mesh")]
+mod collision_from_mesh;
 mod constraints;
 mod events;
 mod gravity;
@@ -72,10 +76,13 @@ impl Plugin for CorePlugin {
             .register_type::<RotationConstraints>()
             .register_type::<CollisionLayers>()
             .register_type::<SensorShape>()
-            .add_system_to_stage(CoreStage::First, PhysicsSteps::update.system())
+            .add_system_to_stage(CoreStage::First, PhysicsSteps::update)
             .add_stage_before(CoreStage::PostUpdate, crate::stage::ROOT, {
                 Schedule::default().with_stage(crate::stage::UPDATE, SystemStage::parallel())
             });
+
+        #[cfg(feature = "collision-from-mesh")]
+        app.add_system(collision_from_mesh::pending_collision_system);
     }
 }
 
